netapp_ontap.models.volume_rebalancing1_engine_movement_last_error API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.volume_rebalancing1_engine_movement_last_error`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class VolumeRebalancing1EngineMovementLastErrorSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the VolumeRebalancing1EngineMovementLastError object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `code: Size GET`

    Error code of the last file move error on the constituent.

  `destination: Size GET`

    DSID of the destination constituent of the last file move error on the constituent.

  `file_id: Size GET`

    File ID of the last file move error on the constituent.

  `time: ImpreciseDateTime GET`

    Time of the last file move error on the constituent.

    Example: 2018-06-04T19:00:00.000+0000